From 027fdc36f5f5c08086a8e7cabb7b05e93b7fdcbb Mon Sep 17 00:00:00 2001
From: Cyril Brulebois <ckb@riseup.net>
Date: Mon, 14 Jan 2019 03:47:46 +0100
Subject: [PATCH] Test suite: check for known issues to avoid wasting time
 (refs: #12142, #16314).

We're kind of stuck between a rock and a hard place at the moment, as
the src:qemu package in stretch has a very annoying bug (#12142 aka.
Debian#851694), making various operations fail.

It was fine to let it fly for a while as all test suite specialists
were running unstable, and isotesters have a set of locally patched
qemu packages; it's rather late in the stretch lifecycle to try and
get that fixed there, and we aren't ready to switch to buster anyway
because the test suite is broken with Java 9+ (#15460).

As a consequence, implement an extra check on the version of a given
qemu package, making sure to point the oblivious test suite users at
the freshly documented workaround.
---
 run_test_suite | 14 ++++++++++++++
 1 file changed, 14 insertions(+)

diff --git a/run_test_suite b/run_test_suite
index 57c7f08d27..39538f8b9a 100755
--- a/run_test_suite
+++ b/run_test_suite
@@ -129,6 +129,19 @@ check_dependencies() {
     done
 }
 
+check_known_issues() {
+    if grep -qs '^9\.' /etc/debian_version; then
+        qemu_binary='qemu-system-x86'
+        qemu_expected='1:2.8+dfsg-6.0tails1'
+        qemu_version=$(dpkg-query -f '${Version}' -W "$qemu_binary" 2>/dev/null || echo none)
+        if [ "$qemu_version" != "$qemu_expected" ]; then
+            echo "Your set of QEMU packages doesn't have the expected version (got: $qemu_version, expected: $qemu_expected)"
+            echo "Please refer to the \"Known issues\" section of the test/setup.mdwn documentation."
+            exit 1
+        fi
+    fi
+}
+
 display_in_use() {
     [ -e "/tmp/.X${1#:}-lock" ] || [ -e "/tmp/.X11-unix/X${1#:}" ]
 }
@@ -263,6 +276,7 @@ done
 trap "test_suite_cleanup" EXIT HUP INT QUIT TERM
 
 check_dependencies ${GENERAL_DEPENDENCIES}
+check_known_issues
 
 TARGET_DISPLAY=$(next_free_display)
 
-- 
2.11.0

